#include <stdio.h>
#include <stdlib.h>

#define MAGIC "EEPROMIMG"
#define MAGIC_OFFSET 0x1F9E0

int main(int argc, char **argv) {
	FILE *bootloader_file;
	FILE *eeprom_file;
	unsigned char eeprom_image[256];
	unsigned char magic[9];

	if (argc < 3) {		
		fprintf(stderr, "Usage : %s bootloader_file eeprom_file\n", argv[0]);
		exit(1);
	}

	bootloader_file = fopen(argv[1], "r+b");
	if (!bootloader_file) {
		fprintf(stderr, "Cannot find bootloader %s\n", argv[1]);
		exit(1);
	}
	eeprom_file = fopen(argv[2], "rb");
	if (!eeprom_file) {
		fprintf(stderr, "Cannot find EEprom %s\n", argv[2]);
		exit(1);
	}
	fseek(eeprom_file, 0, SEEK_END);
	if (ftell(eeprom_file) != sizeof(eeprom_image)) {
		fprintf(stderr, "Invalid EEprom file %s\n", argv[2]);
		exit(1);
	}
	fseek(eeprom_file, 0, SEEK_SET);
	if (fread(eeprom_image, 1, sizeof(eeprom_image), eeprom_file) != sizeof(eeprom_image)) {
		fprintf(stderr, "Error reading EEprom file %s\n", argv[2]);
		exit(1);
	}
	fclose(eeprom_file);
	fseek(bootloader_file, MAGIC_OFFSET, SEEK_SET);
	if (fread(magic, 1, sizeof(magic), bootloader_file) != sizeof(magic) ||
	    memcmp(magic, MAGIC, sizeof(magic)) != 0) {
		fprintf(stderr, "Invalid or not blank bootloader file %s\n", argv[1]);
		exit(1);
	}
	fseek(bootloader_file, MAGIC_OFFSET, SEEK_SET);
	if (fwrite(eeprom_image, 1, sizeof(eeprom_image), bootloader_file) != sizeof(eeprom_image)) {
		fprintf(stderr, "Error patching bootloader %s\n", argv[1]);
		exit(1);
	}
	fclose(bootloader_file);

	printf("Bootloader successfuly patched - happy rescuing :)\n");

	return 0;
}	
		
